@@ -100,11 +100,11 @@ class Simulation:
         r = f"Simulation(chid={self.chid},\n" + \
             f"           meshes={len(self.meshes)},\n" + \
             (f"           obstructions={len(self.obstructions)},\n" if len(self.obstructions) > 0 else "") + \
-            (f"           geometries={len(self.geoms)},\n" if len(self.geoms) > 0 else "") + \
+            (f"           geoms={len(self.geoms)},\n" if len(self.geoms) > 0 else "") + \
             (f"           slices={len(self.slices)},\n" if len(self.slices) > 0 else "") + \
-            (f"           slices={len(self.geomslices)},\n" if len(self.geomslices) > 0 else "") + \
-            (f"           plot3d={len(self.data_3d)},\n" if len(self.data_3d) > 0 else "") + \
-            (f"           smoke3d={len(self.smoke_3d)},\n" if len(self.smoke_3d) > 0 else "") + \
+            (f"           geomslices={len(self.geomslices)},\n" if len(self.geomslices) > 0 else "") + \
+            (f"           data_3d={len(self.data_3d)},\n" if len(self.data_3d) > 0 else "") + \
+            (f"           smoke_3d={len(self.smoke_3d)},\n" if len(self.smoke_3d) > 0 else "") + \
             (f"           isosurfaces={len(self.isosurfaces)},\n" if len(self.isosurfaces) > 0 else "") + \
             (f"           particles={len(self.particles)},\n" if len(self.particles) > 0 else "") + \
             (f"           evacs={len(self.evacs)},\n" if len(self.evacs) > 0 else "") + \
